==> haskell-hasql-notifications-0.2.0.0-122-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hasql-notifications.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hasql-notifications
version:              0.2.0.0
visibility:           public
id:                   hasql-notifications-0.2.0.0-3j99OJRCFUoDrOOw6hdYyo
key:                  hasql-notifications-0.2.0.0-3j99OJRCFUoDrOOw6hdYyo
license:              BSD-3-Clause
copyright:            2020 Diogo Biazus
maintainer:           diogo@biazus.ca
author:               Diogo Biazus
homepage:             https://github.com/diogob/hasql-notifications
synopsis:             LISTEN/NOTIFY support for Hasql
description:
    Use PostgreSQL Asynchronous notification support with your Hasql Types.

category:             Hasql, Database, PostgreSQL
abi:                  7308331ba669b3f6c6808249fcd4689c
exposed:              True
exposed-modules:      Hasql.Notifications
import-dirs:          /usr/lib/ghc-9.0.2/site-local/hasql-notifications-0.2.0.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/hasql-notifications-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hasql-notifications
hs-libraries:         HShasql-notifications-0.2.0.0-3j99OJRCFUoDrOOw6hdYyo
depends:
    base-4.15.1.0 bytestring-0.10.12.1
    contravariant-1.5.5-FtJyCLyWfutGN2UWoJs8qd
    hasql-1.5-646ouBFKQ9u87DyUVclCNE
    hasql-pool-0.5.2.2-7Sp9MPCd25eK6wNxMscBlx
    postgresql-libpq-0.9.4.3-IkP6G59sk5XEvvBwPSqWYy text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-hasql-notifications/html/hasql-notifications.haddock

haddock-html:         /usr/share/doc/haskell-hasql-notifications/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hasql-notifications-0.2.0.1-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hasql-notifications.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hasql-notifications
version:              0.2.0.1
visibility:           public
id:                   hasql-notifications-0.2.0.1-E4WhmpcAW4ILmP1q9TTma7
key:                  hasql-notifications-0.2.0.1-E4WhmpcAW4ILmP1q9TTma7
license:              BSD-3-Clause
copyright:            2020 Diogo Biazus
maintainer:           diogo@biazus.ca
author:               Diogo Biazus
homepage:             https://github.com/diogob/hasql-notifications
synopsis:             LISTEN/NOTIFY support for Hasql
description:
    Use PostgreSQL Asynchronous notification support with your Hasql Types.

category:             Hasql, Database, PostgreSQL
abi:                  df5e9b68dc24b4d8cd015276b17cc636
exposed:              True
exposed-modules:      Hasql.Notifications
import-dirs:          /usr/lib/ghc-9.0.2/site-local/hasql-notifications-0.2.0.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/hasql-notifications-0.2.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hasql-notifications
hs-libraries:         HShasql-notifications-0.2.0.1-E4WhmpcAW4ILmP1q9TTma7
depends:
    base-4.15.1.0 bytestring-0.10.12.1
    hasql-1.5.0.1-JoE9F9hVD7DLJd1ptLnU0F
    hasql-pool-0.5.2.2-JyuNyrsTOolBwjT1DWgdVA
    postgresql-libpq-0.9.4.3-IkP6G59sk5XEvvBwPSqWYy text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-hasql-notifications/html/hasql-notifications.haddock

haddock-html:         /usr/share/doc/haskell-hasql-notifications/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
